#!/usr/local/bin/python
#------------------------------------------------------------------------------
# Copyright (c) 2007-2014 Perforce Software, Inc.  Provided for use as defined in
# the Perforce Consulting Services Agreement.
#------------------------------------------------------------------------------

"""
Usage:
	python protect_groups.py [instance] protect_groups.txt > remove_groups.txt

instance defaults to 1 if not given.

This script will list all the groups mentioned in "p4 protect" that are not a Perforce group.
You need to pull the groups from p4 protect with:

p4 protect -o | grep group |  cut -d " " -f 3 | sort | uniq > protect_groups.txt and pass protect_groups.txt to this script.
"""

import os
import re
import string
import sys
import platform
import ConfigParser

if len(sys.argv) > 1:
  P4INSTANCE = str(sys.argv[1])
  protect_groups = sys.argv[2]
else:
  P4INSTANCE = '1'
  protect_groups = sys.argv[1]

config = ConfigParser.RawConfigParser()
config.read('maintenance.cfg')

##########################################################################
#####                                                                #####
#####  CONFIGURATION VARIABLES: Modify in maintenance.cfg as needed. #####
#####                                                                #####

server = (config.get(P4INSTANCE, 'server'))
p4user = (config.get(P4INSTANCE, 'p4user'))
passwd = (config.get(P4INSTANCE, 'passwd'))

if platform.system() == "Windows": 
  p4="p4.exe -p %s -u %s" % (server, p4user)
else:
  p4="/p4/1/bin/p4_1  -p %s -u %s" % (server, p4user)

os.system('echo %s| %s login' % (passwd, p4))

p4groups = []
groupusers = []

def main():
  if len(sys.argv) < 1:
    print("This script requires a file with the list of groups in the protections table as a parameter. See the top of the script for instructions.")

  try:
    for group in os.popen( "%s groups" % p4 ).readlines():
      group = group.rstrip()
      group = group.lower()
      p4groups.append( group )
  except:
    print("Non unicode group name on server. Some group names may have been skipped.")

  input = open( protect_groups, "r" )

  for line in input.readlines():
    line = line.rstrip()
    line = line.lower()
    if line in p4groups:
      continue
    else:
      print(line)
  input.close()

###############################################################################
# main
if __name__ == "__main__":
  main()